Struct ipnetwork::Ipv4Network [−][src]
pub struct Ipv4Network { /* fields omitted */ }Represents a network range where the IP addresses are of v4
Methods
impl Ipv4Network[src]
impl Ipv4Networkpub fn new(addr: Ipv4Addr, prefix: u8) -> Result<Ipv4Network, IpNetworkError>[src]
pub fn new(addr: Ipv4Addr, prefix: u8) -> Result<Ipv4Network, IpNetworkError>Constructs a new Ipv4Network from any Ipv4Addr and a prefix denoting the network size.
If the prefix is larger than 32 this will return an IpNetworkError::InvalidPrefix.
pub fn iter(&self) -> Ipv4NetworkIterator[src]
pub fn iter(&self) -> Ipv4NetworkIteratorReturns an iterator over Ipv4Network. Each call to next will return the next
Ipv4Addr in the given network. None will be returned when there are no more
addresses.
pub fn ip(&self) -> Ipv4Addr[src]
pub fn ip(&self) -> Ipv4Addrpub fn prefix(&self) -> u8[src]
pub fn prefix(&self) -> u8pub fn mask(&self) -> Ipv4Addr[src]
pub fn mask(&self) -> Ipv4AddrReturns the mask for this Ipv4Network.
That means the prefix most significant bits will be 1 and the rest 0
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net: Ipv4Network = "127.0.0.0/16".parse().unwrap(); assert_eq!(net.mask(), Ipv4Addr::new(255, 255, 0, 0));
pub fn network(&self) -> Ipv4Addr[src]
pub fn network(&self) -> Ipv4AddrReturns the address of the network denoted by this Ipv4Network.
This means the lowest possible IPv4 address inside of the network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net: Ipv4Network = "10.1.9.32/16".parse().unwrap(); assert_eq!(net.network(), Ipv4Addr::new(10, 1, 0, 0));
pub fn broadcast(&self) -> Ipv4Addr[src]
pub fn broadcast(&self) -> Ipv4AddrReturns the broadcasting address of this Ipv4Network.
This means the highest possible IPv4 address inside of the network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net: Ipv4Network = "10.9.0.32/16".parse().unwrap(); assert_eq!(net.broadcast(), Ipv4Addr::new(10, 9, 255, 255));
pub fn contains(&self, ip: Ipv4Addr) -> bool[src]
pub fn contains(&self, ip: Ipv4Addr) -> boolChecks if a given Ipv4Addr is in this Ipv4Network
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net: Ipv4Network = "127.0.0.0/24".parse().unwrap(); assert!(net.contains(Ipv4Addr::new(127, 0, 0, 70))); assert!(!net.contains(Ipv4Addr::new(127, 0, 1, 70)));
pub fn size(&self) -> u64[src]
pub fn size(&self) -> u64Returns number of possible host addresses in this Ipv4Network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net: Ipv4Network = "10.1.0.0/16".parse().unwrap(); assert_eq!(net.size(), 65536); let tinynet: Ipv4Network = "0.0.0.0/32".parse().unwrap(); assert_eq!(tinynet.size(), 1);
pub fn nth(&self, n: u32) -> Option<Ipv4Addr>[src]
pub fn nth(&self, n: u32) -> Option<Ipv4Addr>Returns the n:th address within this network.
The adresses are indexed from 0 and n must be smaller than the size of the network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net: Ipv4Network = "192.168.0.0/24".parse().unwrap(); assert_eq!(net.nth(0).unwrap(), Ipv4Addr::new(192, 168, 0, 0)); assert_eq!(net.nth(15).unwrap(), Ipv4Addr::new(192, 168, 0, 15)); assert!(net.nth(256).is_none()); let net2: Ipv4Network = "10.0.0.0/16".parse().unwrap(); assert_eq!(net2.nth(256).unwrap(), Ipv4Addr::new(10, 0, 1, 0));