Struct ipnetwork::Ipv4Network
[−]
[src]
pub struct Ipv4Network {
// some fields omitted
}Methods
impl Ipv4Network[src]
fn new(addr: Ipv4Addr, prefix: u8) -> Result<Ipv4Network, IpNetworkError>
Constructs a new Ipv4Network from any Ipv4Addr and a prefix denoting the network size.
If the prefix is larger than 32 this will return an IpNetworkError::InvalidPrefix.
fn from_cidr(cidr: &str) -> Result<Ipv4Network, IpNetworkError>
Creates an Ipv4Network from parsing a string in CIDR notation.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let new = Ipv4Network::new(Ipv4Addr::new(10, 1, 9, 32), 16).unwrap(); let from_cidr = Ipv4Network::from_cidr("10.1.9.32/16").unwrap(); assert_eq!(new.ip(), from_cidr.ip()); assert_eq!(new.prefix(), from_cidr.prefix());
fn iter(&self) -> Ipv4NetworkIterator
Returns an iterator over Ipv4Network. Each call to next will return the next
Ipv4Addr in the given network. None will be returned when there are no more
addresses.
fn ip(&self) -> Ipv4Addr
fn prefix(&self) -> u8
fn mask(&self) -> Ipv4Addr
Returns the mask for this Ipv4Network.
That means the prefix most significant bits will be 1 and the rest 0
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net = Ipv4Network::from_cidr("127.0.0.0/16").unwrap(); assert_eq!(net.mask(), Ipv4Addr::new(255, 255, 0, 0));
fn network(&self) -> Ipv4Addr
Returns the address of the network denoted by this Ipv4Network.
This means the lowest possible IPv4 address inside of the network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net = Ipv4Network::from_cidr("10.1.9.32/16").unwrap(); assert_eq!(net.network(), Ipv4Addr::new(10, 1, 0, 0));
fn broadcast(&self) -> Ipv4Addr
Returns the broadcasting address of this Ipv4Network.
This means the highest possible IPv4 address inside of the network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net = Ipv4Network::from_cidr("10.9.0.32/16").unwrap(); assert_eq!(net.broadcast(), Ipv4Addr::new(10, 9, 255, 255));
fn contains(&self, ip: Ipv4Addr) -> bool
Checks if a given Ipv4Addr is in this Ipv4Network
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net = Ipv4Network::from_cidr("127.0.0.0/24").unwrap(); assert!(net.contains(Ipv4Addr::new(127, 0, 0, 70))); assert!(!net.contains(Ipv4Addr::new(127, 0, 1, 70)));
fn size(&self) -> u64
Returns number of possible host addresses in this Ipv4Network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net = Ipv4Network::from_cidr("10.1.0.0/16").unwrap(); assert_eq!(net.size(), 65536); let tinynet = Ipv4Network::from_cidr("0.0.0.0/32").unwrap(); assert_eq!(tinynet.size(), 1);
fn nth(&self, n: u32) -> Option<Ipv4Addr>
Returns the n:th address within this network.
The adresses are indexed from 0 and n must be smaller than the size of the network.
Examples
use std::net::Ipv4Addr; use ipnetwork::Ipv4Network; let net = Ipv4Network::from_cidr("192.168.0.0/24").unwrap(); assert_eq!(net.nth(0).unwrap(), Ipv4Addr::new(192, 168, 0, 0)); assert_eq!(net.nth(15).unwrap(), Ipv4Addr::new(192, 168, 0, 15)); assert!(net.nth(256).is_none()); let net2 = Ipv4Network::from_cidr("10.0.0.0/16").unwrap(); assert_eq!(net2.nth(256).unwrap(), Ipv4Addr::new(10, 0, 1, 0));